/*
 * File: REMINST.CMD
 *
 * Setup for remote installation of OS/2 over network.
 * To be run on the 'code server' system.
 *
 * Bob Eager   November 2002
 *
 */

/* Initialisation */

trace off
signal on halt name endit
drop g. msgs.
g.alphanum = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789'

call msg_setup

call RxFuncAdd 'SysLoadFuncs', 'REXXUTIL', 'SysLoadFuncs'
call SysLoadFuncs

/* Introduction */

call putmsg 1

/* Get drive specifications and try to work out CDROM drive */

g.cdrom = ''
dmap = SysDriveMap('C', 'LOCAL')
do i = 1 to words(dmap)
   if stream(word(dmap, i)'\INFO\NP', 'C', 'QUERY EXISTS') \= '' then do
      g.cdrom = word(dmap, i)
      leave
   end
end

/* Find out boot drive */

g.bootdrv = SysBootDrive()

/* Give user a chance to change the choice of CDROM drive */

do forever
   call putmsg 3,substr(g.cdrom,1,1)
   parse upper pull temp
   if (length(temp) = 0) then leave     /* Use default */
   if length(temp) > 2 then do
      call putmsg 4
      iterate
   end
   if length(temp) = 1 then temp = temp':'
   if stream(temp'\INFO\NP', 'C', 'QUERY EXISTS') = '' then do
      call putmsg 5
      iterate
   end
   g.cdrom = temp
   leave
end

/* Do the real work */

call code_server g. msgs.               /* Set up code server */

call inst_diskettes g. msgs.            /* Make installation diskettes */

call putmsg 2

exit 0

endit:
say 'Interrupted - exiting'
exit 1


/*-------------------------------------------------------------------
 *              Set up code server
 *-----------------------------------------------------------------*/

code_server:   procedure expose g. msgs.

call putmsg 11

/* Give user a chance to change the choice of SRVIFS directory */

g.srvdir = g.bootdrv'\SRVIFS'
call putmsg 6,g.bootdrv||'\SRVIFS'
parse upper pull temp
if temp = '' then temp = g.bootdrv||'\SRVIFS'
call SysRmDir temp
call SysMkDir temp
g.srvdir = temp
temp = temp'\IBMCOM'
call SysMkDir temp
temp = temp'\MACS'
call SysMkDir temp
g.macdir = temp

/* Give user a chance to change the choice of server name */

g.srvname = 'CIDSRV'
do forever
   call putmsg 7,g.srvname
   parse upper pull temp
   call strip temp
   if (length(temp) = 0) then leave     /* Use default */
   if (length(temp) > 15) | (verify(temp, g.alphanum) \= 0) then do
      call putmsg 8
      iterate
   end
   g.srvname = temp
   leave
end

/* Copy across the SRVIFS files */

'@xcopy' g.cdrom'\CID\SRVIFS' g.srvdir '>nul'

/* Make the SERVICE.INI file */

call make_ini

/* Handle any NIC driver diskette */

g.nifdrv = ''
g.nifname = ''
do forever
   call putmsg 10
   parse upper pull temp
   if (length(temp) = 0) then leave     /* No driver diskette */
   if length(temp) > 2 then do
      call putmsg 4
      iterate
   end
   if length(temp) = 1 then temp = temp':'
   g.nifdrv = temp
   leave
end

if g.nifdrv \= '' then do
   '@copy' g.nifdrv'\' g.macdir '>nul'
   call SysFileTree g.nifdrv'\*.NIF', 'f', 'FO'
   if f.0 = 1 then do                   /* Exactly one NIF - useful! */
      g.nifname = filespec('N',f.1)
   end
   say ''
   say 'Remove the driver diskette from drive' g.nifdrv', then press Enter.'
   parse pull temp
end

return


/*-------------------------------------------------------------------
 *              Create the SERVICE.INI file
 *-----------------------------------------------------------------*/

make_ini:   procedure expose g. msgs.

ini = g.srvdir||'\SERVICE.INI'

call SysFileDelete ini
res = stream(ini, 'C', 'OPEN WRITE')
if res \= 'READY:' then do
   call putmsg 9
   exit 1
end

call lineout ini, 'Name =' g.srvname
call lineout ini, 'GroupName = No'
call lineout ini, 'Path =' g.cdrom'\'
call lineout ini, 'PerClient = No'
call lineout ini, 'PermitWrite = No'
call lineout ini, 'MaxClients = 2'
call lineout ini, 'Alias = ReadOnly,Single,CDROM,'g.cdrom'\'
call lineout ini, 'Alias = ReadWrite,Single,STATUS,'g.srvdir

call stream ini, 'C', 'CLOSE'

return


/*-------------------------------------------------------------------
 *              Start the code server
 *-----------------------------------------------------------------*/

start_server:   procedure expose g. msgs.

return


/*-------------------------------------------------------------------
 *              Set up installation diskettes
 *-----------------------------------------------------------------*/

inst_diskettes:   procedure expose g. msgs.

call putmsg 12

fd = 'A:'
do forever
   call putmsg 13, substr(fd,1,1)
   parse upper pull temp
   if (length(temp) = 0) then leave     /* No driver diskette */
   if length(temp) > 2 then do
      call putmsg 4
      iterate
   end
   if length(temp) = 1 then temp = temp':'
   fd = temp
   leave
end

call putmsg 14                          /* Preamble about SEDISK */

/* Make the base diskettes */

'@'g.cdrom'\CID\EXE\OS2\SEDISK /S:'g.cdrom'\OS2IMAGE /T:'fd

/* Add networking support */

do forever                              /* Get name of NIF file */
   call putmsg 15,g.nifname
   parse upper pull temp
   if temp \= '' then g.nifname = temp
   if (length(g.nifname) \= 0) then leave    /* No default */
end

call check_for fd,'DISK 2','Remote Diskette 2'
add = ''
if g.nifdrv \= '' then add = '/ADD:'g.macdir

call putmsg 17                          /* Advise what is next */
call putmsg 16                          /* Warn about diskette change */

'@'g.cdrom'\CID\SERVER\MPTS\THINLAPS' g.cdrom'\CID\SERVER\MPTS' fd,
   g.nifname '/TU:'fd add

/* Add THINIFS support */

call check_for fd,'DISK 2','Remote Diskette 2'

call putmsg 18                          /* Advise what is next */
call putmsg 16                          /* Warn about diskette change */

'@'g.cdrom'\CID\SRVIFS\THINIFS /D:Z /S:'g.cdrom'\CID\SRVIFS /T:'fd,
   '/TU:'fd '/SRV:\\'g.srvname'\CDROM' '/REQ:*'
'@'g.cdrom'\CID\SRVIFS\THINIFS /D:W /S:'g.cdrom'\CID\SRVIFS /T:'fd,
   '/TU:'fd '/SRV:\\'g.srvname'\STATUS' '/REQ:*'

/* Modify CONFIG.SYS */

call check_for fd,'DISK 1','Remote Diskette 1'
call putmsg 19                          /* Advise what is happening */

csys = fd'\CONFIG.SYS'

cslines.0 = 6
cslines.1 = 'SET OS2_SHELL=CDBOOT.EXE'
cslines.2 = 'SET OEMPROGRAM=\IBMINST\NPCONFIG.EXE'
cslines.3 = 'SET EXITWHENDONE=1'
cslines.4 = 'SET SAVECONNECT=1'
cslines.5 = 'SET ADAPTER_NIF='g.nifname
cslines.6 = 'SET SRVNAME1='g.srvname

do i = 1 to cslines.0
   call lineout csys, cslines.i
end
call stream csys, 'C', 'CLOSE'

/* Add final files to diskette 2 */

call putmsg 20

call check_for fd,'DISK 2','Remote Diskette 2'
'@copy' g.cdrom'\OS2IMAGE\DISK_2\CDBOOT.EXE' fd'\ >nul'
'@attrib -r' fd'\*'

return


/*-------------------------------------------------------------------
 *              Check that a particular diskette is in a drive
 *-----------------------------------------------------------------*/

check_for:   procedure expose g. msgs.

fd = arg(1)
want = arg(2)
name = arg(3)

do forever
   temp = SysDriveInfo(fd)
   parse var temp . . . label
   if label = want then leave
   say 'Insert' name 'in drive' fd 'and then press Enter'
   parse pull temp
end

return


/*-------------------------------------------------------------------
 *              Output a message
 *-----------------------------------------------------------------*/

putmsg:   procedure expose msgs.

msgno = arg(1)
default = arg(2)

if default \= '' then
   default = '['default']:'

do i = 1 to msgs.msgno.0
   s = msgs.msgno.i
   if i = msgs.msgno.0 then s = s msgs.bright||default||msgs.normal
   say s
end

return


/*-------------------------------------------------------------------
 *              Set up message lists
 *-----------------------------------------------------------------*/

msg_setup:   procedure expose msgs.

msgs.bright = x2c('1B')||'[1m'
msgs.normal = x2c('1B')||'[0m'

msgs.0 = 20

msgs.1.0 = 9
msgs.1.1 = 'ͻ'
msgs.1.2 = ' This command sets up the code server and makes remote        '
msgs.1.3 = ' installation diskettes. Many questions have default answers, '
msgs.1.4 = ' shown in square brackets; to use these, just press Enter.    '
msgs.1.5 = ' Make sure that, if using a network interface card not        '
msgs.1.6 = ' supported by OS/2 as distributed, you have a diskette which  '
msgs.1.7 = ' contains the driver and associated NIF file.                 '
msgs.1.8 = 'ͼ'
msgs.1.9 = ''

msgs.2.0 = 9
msgs.2.1 = 'To start the code server, go to the code server directory'
msgs.2.2 = 'and issue the command:'
msgs.2.3 = '        SERVICE /INI=SERVICE'
msgs.2.4 = 'To see its status, go to the code server directory and'
msgs.2.5 = 'issue the command:'
msgs.2.6 = '        SERVICE /S'
msgs.2.7 = 'To stop the code server immediately, issue the command:'
msgs.2.8 = '        SERVICE/F'
msgs.2.9 = ''

msgs.3.0 = 1
msgs.3.1 = 'Enter the drive letter for the OS/2 CDROM'

msgs.4.0 = 1
msgs.4.1 = 'This is not a valid drive specification'

msgs.5.0 = 1
msgs.5.1 = 'This is not a valid OS/2 installation source medium'

msgs.6.0 = 2
msgs.6.1 = 'Enter the full path of the directory where the server'
msgs.6.2 = 'files are to be stored'

msgs.7.0 = 3
msgs.7.1 = 'Enter a name for the code server; it must be a unique NETBIOS'
msgs.7.2 = 'name on your network, and it must be between 1 and 15'
msgs.7.3 = 'alphanumeric characters in length'

msgs.8.0 = 1
msgs.8.1 = 'This is not a valid server name'

msgs.9.0 = 1
msgs.9.1 = 'Cannot create SERVICE.INI file - exiting'

msgs.10.0 = 5
msgs.10.1 = 'If you have a driver diskette for your network interface'
msgs.10.2 = 'card, place it in the drive now, and enter the drive letter'
msgs.10.3 = 'here. If the card is supported by OS/2 as distributed, just'
msgs.10.4 = 'press Enter.'
msgs.10.5 = 'Driver diskette letter:'

msgs.11.0 = 4
msgs.11.1 = 'Ŀ'
msgs.11.2 = '           S E R V E R   S E T U P                            '
msgs.11.3 = ''
msgs.11.4 = ''

msgs.12.0 = 4
msgs.12.1 = 'Ŀ'
msgs.12.2 = '           C R E A T E   B O O T   D I S K E T T E S          '
msgs.12.3 = ''
msgs.12.4 = ''

msgs.13.0 = 2
msgs.13.1 = 'Enter the drive letter for the diskette drive in which the'
msgs.13.2 = 'remote installation boot diskettes will be created'

msgs.14.0 = 8
msgs.14.1 = 'The remote installation diskettes will now be created.'
msgs.14.2 = 'You will need THREE blank, formatted diskettes; label them'
msgs.14.3 = 'as follows:'
msgs.14.4 = '   Remote Installation Diskette (D0)'
msgs.14.5 = '   Remote Diskette 1 (D1)'
msgs.14.6 = '   Remote Diskette 2 (D2)'
msgs.14.7 = 'When prompted, insert these in the order: D0, D1, D2.'
msgs.14.8 = ''

msgs.15.0 = 3
msgs.15.1 = ''
msgs.15.2 = 'Enter the name of the NIF file for the network interface'
msgs.15.3 = 'to be used on the target system.'

msgs.16.0 = 5
msgs.16.1 = ''
msgs.16.2 = 'When a message appears indicating that CONFIG.SYS cannot'
msgs.16.3 = 'be updated, remove Remote Diskette 2 and insert Remote'
msgs.16.4 = 'Diskette 1. Then press Enter.'
msgs.16.5 = ''

msgs.17.0 = 1
msgs.17.1 = 'About to add networking support to the diskettes...'

msgs.18.0 = 1
msgs.18.1 = 'About to add file sharing client to the diskettes...'

msgs.19.0 = 2
msgs.19.1 = ''
msgs.19.2 = 'Making final modifications to CONFIG.SYS...'

msgs.20.0 = 2
msgs.20.1 = ''
msgs.20.2 = 'Adding final files to diskettes...'

return

/*
 * End of file: REMINST.CMD
 *
 */
